import { Component, OnInit } from '@angular/core';
import { NavController } from '@ionic/angular';

@Component({
  selector: 'app-details',
  templateUrl: 'details.page.html',
  styleUrls: ['details.page.scss']
})
export class DetailsPage implements OnInit {
  constructor(private navCtrl: NavController) {}

  // 示例服务列表
  services = [
    {
      title: '健康检查',
      description: '全面的健康检查，包括血液检测、心电图等。',
      doctor: {
        name: '张医生',
        status: this.getDoctorStatus('张医生')
      }
    },
    {
      title: '营养咨询',
      description: '专业的营养师提供个性化的饮食建议。',
      doctor: {
        name: '李医生',
        status: this.getDoctorStatus('李医生')
      }
    },
    {
      title: '心理辅导',
      description: '专业的心理咨询师提供心理支持和辅导。',
      doctor: {
        name: '王医生',
        status: this.getDoctorStatus('王医生')
      }
    }
  ];

  ngOnInit() {
    // 模拟数据更新
    this.updateDoctorStatus();
  }

  // 获取医生状态的方法
  getDoctorStatus(doctorName: string): string {
    const now = new Date();
    const yesterday = new Date(now);
    yesterday.setDate(yesterday.getDate() - 1);

    if (doctorName === '张医生') {
      // 张医生昨天下午3点正在提供咨询服务
      const consultationTime = new Date(yesterday);
      consultationTime.setHours(15, 0, 0, 0); // 下午3点
      if (now >= consultationTime && now < new Date(yesterday.setHours(16, 0, 0, 0))) {
        return '正在提供咨询服务';
      } else {
        return '可预约';
      }
    } else {
      return '可预约';
    }
  }

  // 定时更新医生状态
  updateDoctorStatus() {
    setInterval(() => {
      this.services.forEach(service => {
        service.doctor.status = this.getDoctorStatus(service.doctor.name);
      });
    }, 60000); // 每分钟更新一次
  }

  // 示例方法：返回上一页
  goBack() {
    this.navCtrl.back();
  }
}